@@ -55,18 +55,35 @@ class AcidFS(object):
        If the repository is already created or `create` is False, this argument
        has no effect.
 
+    ``user_name``
+
+       If the Git repository is to be created, set the user name for the
+       repository to this value.  This is the same as creating the repository
+       and running `git config user.name "<user_name>"`.
+
+    ``user_email``
+
+       If the Git repository is to be created, set the user email for the
+       repository to this value.  This is the same as creating the repository
+       and running `git config user.email "<user_email>"`.
+
     ``name``
 
        Name to be used as a sort key when ordering the various databases
        (datamanagers in the parlance of the transaction package) during a
        commit.  It is exceedingly rare that you would need to use anything other
        than the default, here.
+
+    ``path_encoding``
+
+       Encode paths with this encoding. The default is `ascii`.
     """
     session = None
     _cwd = ()
 
     def __init__(self, repo, head='HEAD', create=True, bare=False,
-                 name='AcidFS'):
+                 user_name=None, user_email=None, name='AcidFS',
+                 path_encoding='ascii'):
         wdpath = repo
         dbpath = os.path.join(repo, '.git')
         if not os.path.exists(dbpath):
@@ -81,6 +98,14 @@ class AcidFS(object):
                         wdpath = repo
                         dbpath = os.path.join(repo, '.git')
                     _check_output(args)
+                    if user_name:
+                        args = ['git', 'config', 'user.name', user_name]
+                        _check_output(args, cwd=dbpath)
+                    if user_email:
+                        args = ['git', 'config', 'user.email', user_email]
+                        _check_output(args, cwd=dbpath)
+                    args = ['git', 'config', 'core.quotepath', 'false']
+                    _check_output(args, cwd=dbpath)
                 else:
                     raise ValueError('No database found in %s' % dbpath)
 
@@ -88,13 +113,15 @@ class AcidFS(object):
         self.db = dbpath
         self.head = head
         self.name = name
+        self.path_encoding = path_encoding
 
     def _session(self):
         """
         Make sure we're in a session.
         """
         if not self.session or self.session.closed:
-            self.session = _Session(self.wd, self.db, self.head, self.name)
+            self.session = _Session(self.wd, self.db, self.head, self.name,
+                                    self.path_encoding)
         return self.session
 
     def _mkpath(self, path):
@@ -435,10 +462,11 @@ class _Session(object):
     closed = False
     lockfd = None
 
-    def __init__(self, wd, db, head, name):
+    def __init__(self, wd, db, head, name, path_encoding):
         self.wd = wd
         self.db = db
         self.name = name
+        self.path_encoding = path_encoding
         self.lock_file = os.path.join(db, 'acidfs.lock')
         transaction.get().join(self)
 
@@ -455,10 +483,10 @@ class _Session(object):
             # Existing head, get head revision
             self.prev_commit = _check_output(
                 ['git', 'rev-list', '--max-count=1', head], cwd=db).strip()
-            self.tree = _TreeNode.read(db, self.prev_commit)
+            self.tree = _TreeNode.read(db, self.prev_commit, path_encoding)
         else:
             # New head, no commits yet
-            self.tree = _TreeNode(db) # empty tree
+            self.tree = _TreeNode(db, path_encoding)  # empty tree
             self.prev_commit = None
 
     def set_base(self, ref):
@@ -467,7 +495,8 @@ class _Session(object):
                 "Cannot set base when changes already made in transaction.")
         self.prev_commit = _check_output(
             ['git', 'rev-list', '--max-count=1', ref], cwd=self.db).strip()
-        self.tree = _TreeNode.read(self.db, self.prev_commit)
+        self.tree = _TreeNode.read(self.db, self.prev_commit,
+                                   self.path_encoding)
 
     def find(self, path):
         assert isinstance(path, (list, tuple))
@@ -604,14 +633,27 @@ class _Session(object):
             message = 'AcidFS transaction'
         gitenv = os.environ.copy()
         extension = tx._extension  # "Official" API despite underscore
-        user = extension.get('user')
+        user = extension.get('acidfs_user')
         if not user:
-            user = tx.user
-            if user:
-                user = user.split(None, 1)[1] # strip Zope's "path"
+            user = extension.get('user')
+            if not user:
+                user = tx.user
+                if user:
+                    if user.startswith(' '):
+                        user = user[1:]
+                    else:
+                        # strip Zope's "path"
+                        user = user.split(None, 1)
+                        if len(user) == 2:
+                            user = user[1]
+                        else:
+                            user = user[0]
         if user:
             gitenv['GIT_AUTHOR_NAME'] = gitenv['GIT_COMMITER_NAME'] = user
-        email = extension.get('email')
+
+        email = extension.get('acidfs_email')
+        if not email:
+            email = extension.get('email')
         if email:
             gitenv['GIT_AUTHOR_EMAIL'] = gitenv['GIT_COMMITTER_EMAIL'] = \
                 gitenv['EMAIL'] = email
@@ -728,7 +770,7 @@ class _Session(object):
                     if _isalpha(line[0]) or line.startswith(b'@'):
                         # Done collecting tree lines, only expecting one
                         expect(len(extra_state) == 1, 'Wrong number of lines')
-                        whose, mode, oid, path = extra_state[0].split()
+                        whose, mode, oid, path = _parsetree(extra_state[0])
                         expect(whose == b'their', 'Unexpected whose: %s', whose)
                         expect(mode == b'100644', 'Unexpected mode: %s', mode)
                         parsed = path.decode('ascii').split('/')
@@ -747,11 +789,11 @@ class _Session(object):
                         # Done collecting tree lines, expect two, one for base,
                         # one for our copy, whose sha1s should match
                         expect(len(extra_state) == 2, 'Wrong number of lines')
-                        whose, mode, oid, path = extra_state[0].split()
+                        whose, mode, oid, path = _parsetree(extra_state[0])
                         expect(whose in (b'our', b'base'),
                                'Unexpected whose: %s', whose)
                         expect(mode == b'100644', 'Unexpected mode: %s', mode)
-                        whose, mode, oid2, path2 = extra_state[1].split()
+                        whose, mode, oid2, path2 = _parsetree(extra_state[1])
                         expect(whose in (b'our', b'base'),
                                'Unexpected whose: %s', whose)
                         expect(mode == b'100644', 'Unexpected mode: %s', mode)
@@ -772,12 +814,12 @@ class _Session(object):
                         # Done collecting tree lines, expect three, one for base
                         # and one for each copy
                         expect(len(extra_state) == 3, 'Wrong number of lines')
-                        whose, mode, oid, path = extra_state[0].split()
+                        whose, mode, oid, path = _parsetree(extra_state[0])
                         expect(whose in (b'base', b'our', b'their'),
                                'Unexpected whose: %s', whose)
                         expect(mode == b'100644', 'Unexpected mode: %s', mode)
                         for extra_line in extra_state[1:]:
-                            whose, mode, oid2, path2 = extra_line.split()
+                            whose, mode, oid2, path2 = _parsetree(extra_line)
                             expect(whose in (b'base', b'our', b'their'),
                                    'Unexpected whose: %s', whose)
                             expect(mode == b'100644', 'Unexpected mode: %s',
@@ -815,11 +857,11 @@ class _Session(object):
                         # Done collecting tree lines, expect two, one for base,
                         # one for our copy, whose sha1s should match
                         expect(len(extra_state) == 2, 'Wrong number of lines')
-                        whose, mode, oid, path = extra_state[0].split()
+                        whose, mode, oid, path = _parsetree(extra_state[0])
                         expect(whose in (b'our', b'their'), 'Unexpected whose: %s',
                                whose)
                         expect(mode == b'100644', 'Unexpected mode: %s', mode)
-                        whose, mode, oid2, path2 = extra_state[1].split()
+                        whose, mode, oid2, path2 = _parsetree(extra_state[1])
                         expect(whose in (b'our', b'their'),
                                'Unexpected whose: %s', whose)
                         expect(mode == b'100644', 'Unexpected mode: %s', mode)
@@ -845,22 +887,23 @@ class _TreeNode(object):
     oid = None
 
     @classmethod
-    def read(cls, db, oid):
-        node = cls(db)
+    def read(cls, db, oid, path_encoding):
+        node = cls(db, path_encoding)
         node.oid = oid
         contents = node.contents
         with _popen(['git', 'ls-tree', oid],
                    stdout=subprocess.PIPE, cwd=db) as lstree:
             for line in lstree.stdout.readlines():
-                mode, type, oid, name = line.split()
-                name = _s(name)
+                mode, type, oid, name = _parsetree(line)
+                name = name.decode(path_encoding)
                 oid = _s(oid)
                 contents[name] = (type, oid, None)
 
         return node
 
-    def __init__(self, db):
+    def __init__(self, db, path_encoding):
         self.db = db
+        self.path_encoding = path_encoding
         self.contents = {}
 
     def get(self, name):
@@ -872,7 +915,7 @@ class _TreeNode(object):
         assert type in (b'tree', b'blob')
         if not obj:
             if type == b'tree':
-                obj = _TreeNode.read(self.db, oid)
+                obj = _TreeNode.read(self.db, oid, self.path_encoding)
             else:
                 obj = _Blob(self.db, oid)
             obj.parent = self
@@ -896,7 +939,7 @@ class _TreeNode(object):
         return obj
 
     def new_tree(self, name):
-        node = _TreeNode(self.db)
+        node = _TreeNode(self.db, self.path_encoding)
         node.parent = self
         node.name = name
         self.contents[name] = (b'tree', None, node)
@@ -940,7 +983,7 @@ class _TreeNode(object):
                 proc.stdin.write(b' ')
                 proc.stdin.write(_b(oid))
                 proc.stdin.write(b'\t')
-                proc.stdin.write(_b(name))
+                proc.stdin.write(name.encode(self.path_encoding))
                 proc.stdin.write(b'\n')
             proc.stdin.close()
             oid = proc.stdout.read().strip()
@@ -959,6 +1002,10 @@ class _TreeNode(object):
         return self.oid
 
 
+def _parsetree(line):
+    return line.strip().split(None, 3)
+
+
 class _Blob(object):
 
     def __init__(self, db, oid):
