@@ -124,6 +124,14 @@ class FunctionalTests(unittest.TestCase):
             self.assertEqual(f.read(), b'Hello\n')
         transaction.commit() # Nothing to commit
 
+    def test_read_write_nonascii_name(self):
+        fs = self.make_one(path_encoding='utf-8')
+        filename = b'Hell\xc3\xb2'.decode('utf-8')
+        with fs.open(filename, 'wb') as f:
+            fprint(f, b'Hello')
+        transaction.commit()
+        self.assertEquals(fs.listdir(), [filename])
+
     def test_read_write_text_file(self):
         fs = self.make_one()
         with fs.open('foo', 'wt') as f:
@@ -257,6 +265,20 @@ class FunctionalTests(unittest.TestCase):
         self.assertIn(b'Author: Fred Flintstone <fred@bed.rock>', output)
         self.assertIn(b'A test commit.', output)
 
+    def test_commit_metadata_user_path_is_blank(self):
+        # pyramid_tm calls setUser with '' for path
+        fs = self.make_one()
+        tx = transaction.get()
+        tx.note("A test commit.")
+        tx.setUser('Fred', '')
+        tx.setExtendedInfo('email', 'fred@bed.rock')
+        fs.open('foo', 'wb').write(b'Howdy!')
+        transaction.commit()
+
+        output = _check_output(['git', 'log'], cwd=self.tmp)
+        self.assertIn(b'Author: Fred <fred@bed.rock>', output)
+        self.assertIn(b'A test commit.', output)
+
     def test_commit_metadata_extended_info_for_user(self):
         fs = self.make_one()
         tx = transaction.get()
@@ -469,6 +491,22 @@ class FunctionalTests(unittest.TestCase):
         self.assertFalse(pexists(j(self.tmp, 'one', 'a')))
         self.assertTrue(pexists(j(self.tmp, 'one', 'b', 'a')))
 
+    def test_mv_noop(self):
+        """
+        Tests an error report from Hasan Karahan.
+        """
+        fs = self.make_one()
+        fs.open('foo', 'wb').write(b'Hello!')
+        fs.mv('foo', 'foo')
+        self.assertEqual(fs.open('foo', 'rb').read(), b'Hello!')
+        transaction.commit()
+        self.assertEqual(fs.open('foo', 'rb').read(), b'Hello!')
+
+        fs.mv('foo', 'foo')
+        self.assertEqual(fs.open('foo', 'rb').read(), b'Hello!')
+        transaction.commit()
+        self.assertEqual(fs.open('foo', 'rb').read(), b'Hello!')
+
     def test_listdir(self):
         fs = self.make_one()
         fs.mkdirs('one/a')
@@ -718,6 +756,16 @@ class FunctionalTests(unittest.TestCase):
         self.assertTrue(commit[1].startswith('parent'))
         self.assertTrue(commit[2].startswith('parent'))
 
+    def test_directory_name_with_spaces(self):
+        fs = self.make_one()
+        fs.mkdir("foo bar")
+        with fs.cd("foo bar"):
+            fs.open("foo", "wb").write(b"bar")
+        transaction.commit()
+
+        with fs.cd("foo bar"):
+            self.assertTrue(fs.open("foo", "rb").read(), b"bar")
+
 
 class PopenTests(unittest.TestCase):
 
